# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Alexa for Business'
prefix = 'a4b'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ApproveSkill = Action('ApproveSkill')
AssociateContactWithAddressBook = \
    Action('AssociateContactWithAddressBook')
AssociateDeviceWithRoom = Action('AssociateDeviceWithRoom')
AssociateSkillGroupWithRoom = Action('AssociateSkillGroupWithRoom')
AssociateSkillWithSkillGroup = Action('AssociateSkillWithSkillGroup')
AssociateSkillWithUsers = Action('AssociateSkillWithUsers')
CompleteRegistration = Action('CompleteRegistration')
CreateAddressBook = Action('CreateAddressBook')
CreateBusinessReportSchedule = Action('CreateBusinessReportSchedule')
CreateConferenceProvider = Action('CreateConferenceProvider')
CreateContact = Action('CreateContact')
CreateProfile = Action('CreateProfile')
CreateRoom = Action('CreateRoom')
CreateSkillGroup = Action('CreateSkillGroup')
CreateUser = Action('CreateUser')
DeleteAddressBook = Action('DeleteAddressBook')
DeleteBusinessReportSchedule = Action('DeleteBusinessReportSchedule')
DeleteConferenceProvider = Action('DeleteConferenceProvider')
DeleteContact = Action('DeleteContact')
DeleteDevice = Action('DeleteDevice')
DeleteProfile = Action('DeleteProfile')
DeleteRoom = Action('DeleteRoom')
DeleteRoomSkillParameter = Action('DeleteRoomSkillParameter')
DeleteSkillAuthorization = Action('DeleteSkillAuthorization')
DeleteSkillGroup = Action('DeleteSkillGroup')
DeleteUser = Action('DeleteUser')
DisassociateContactFromAddressBook = \
    Action('DisassociateContactFromAddressBook')
DisassociateDeviceFromRoom = Action('DisassociateDeviceFromRoom')
DisassociateSkillFromSkillGroup = \
    Action('DisassociateSkillFromSkillGroup')
DisassociateSkillFromUsers = Action('DisassociateSkillFromUsers')
DisassociateSkillGroupFromRoom = Action('DisassociateSkillGroupFromRoom')
ForgetSmartHomeAppliances = Action('ForgetSmartHomeAppliances')
GetAddressBook = Action('GetAddressBook')
GetConferencePreference = Action('GetConferencePreference')
GetConferenceProvider = Action('GetConferenceProvider')
GetContact = Action('GetContact')
GetDevice = Action('GetDevice')
GetNetworkProfile = Action('GetNetworkProfile')
GetProfile = Action('GetProfile')
GetRoom = Action('GetRoom')
GetRoomSkillParameter = Action('GetRoomSkillParameter')
GetSkillGroup = Action('GetSkillGroup')
ListBusinessReportSchedules = Action('ListBusinessReportSchedules')
ListConferenceProviders = Action('ListConferenceProviders')
ListDeviceEvents = Action('ListDeviceEvents')
ListSkills = Action('ListSkills')
ListSkillsStoreCategories = Action('ListSkillsStoreCategories')
ListSkillsStoreSkillsByCategory = \
    Action('ListSkillsStoreSkillsByCategory')
ListSmartHomeAppliances = Action('ListSmartHomeAppliances')
ListTags = Action('ListTags')
PutConferencePreference = Action('PutConferencePreference')
PutDeviceSetupEvents = Action('PutDeviceSetupEvents')
PutRoomSkillParameter = Action('PutRoomSkillParameter')
PutSkillAuthorization = Action('PutSkillAuthorization')
RegisterAVSDevice = Action('RegisterAVSDevice')
RegisterDevice = Action('RegisterDevice')
RejectSkill = Action('RejectSkill')
ResolveRoom = Action('ResolveRoom')
RevokeInvitation = Action('RevokeInvitation')
SearchAddressBooks = Action('SearchAddressBooks')
SearchContacts = Action('SearchContacts')
SearchDevices = Action('SearchDevices')
SearchNetworkProfiles = Action('SearchNetworkProfiles')
SearchProfiles = Action('SearchProfiles')
SearchRooms = Action('SearchRooms')
SearchSkillGroups = Action('SearchSkillGroups')
SearchUsers = Action('SearchUsers')
SendInvitation = Action('SendInvitation')
StartDeviceSync = Action('StartDeviceSync')
StartSmartHomeApplianceDiscovery = \
    Action('StartSmartHomeApplianceDiscovery')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAddressBook = Action('UpdateAddressBook')
UpdateBusinessReportSchedule = Action('UpdateBusinessReportSchedule')
UpdateConferenceProvider = Action('UpdateConferenceProvider')
UpdateContact = Action('UpdateContact')
UpdateDevice = Action('UpdateDevice')
UpdateProfile = Action('UpdateProfile')
UpdateRoom = Action('UpdateRoom')
UpdateSkillGroup = Action('UpdateSkillGroup')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Elastic Container Service for Kubernetes'
prefix = 'eks'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateCluster = Action('CreateCluster')
CreateFargateProfile = Action('CreateFargateProfile')
CreateNodegroup = Action('CreateNodegroup')
DeleteCluster = Action('DeleteCluster')
DeleteFargateProfile = Action('DeleteFargateProfile')
DeleteNodegroup = Action('DeleteNodegroup')
DescribeCluster = Action('DescribeCluster')
DescribeFargateProfile = Action('DescribeFargateProfile')
DescribeNodegroup = Action('DescribeNodegroup')
DescribeUpdate = Action('DescribeUpdate')
ListClusters = Action('ListClusters')
ListFargateProfiles = Action('ListFargateProfiles')
ListNodegroups = Action('ListNodegroups')
ListTagsForResource = Action('ListTagsForResource')
ListUpdates = Action('ListUpdates')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateClusterConfig = Action('UpdateClusterConfig')
UpdateClusterVersion = Action('UpdateClusterVersion')
UpdateNodegroupConfig = Action('UpdateNodegroupConfig')
UpdateNodegroupVersion = Action('UpdateNodegroupVersion')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS App Mesh'
prefix = 'appmesh'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateGatewayRoute = Action('CreateGatewayRoute')
CreateMesh = Action('CreateMesh')
CreateRoute = Action('CreateRoute')
CreateVirtualGateway = Action('CreateVirtualGateway')
CreateVirtualNode = Action('CreateVirtualNode')
CreateVirtualRouter = Action('CreateVirtualRouter')
CreateVirtualService = Action('CreateVirtualService')
DeleteGatewayRoute = Action('DeleteGatewayRoute')
DeleteMesh = Action('DeleteMesh')
DeleteRoute = Action('DeleteRoute')
DeleteVirtualGateway = Action('DeleteVirtualGateway')
DeleteVirtualNode = Action('DeleteVirtualNode')
DeleteVirtualRouter = Action('DeleteVirtualRouter')
DeleteVirtualService = Action('DeleteVirtualService')
DescribeGatewayRoute = Action('DescribeGatewayRoute')
DescribeMesh = Action('DescribeMesh')
DescribeRoute = Action('DescribeRoute')
DescribeVirtualGateway = Action('DescribeVirtualGateway')
DescribeVirtualNode = Action('DescribeVirtualNode')
DescribeVirtualRouter = Action('DescribeVirtualRouter')
DescribeVirtualService = Action('DescribeVirtualService')
ListGatewayRoutes = Action('ListGatewayRoutes')
ListMeshes = Action('ListMeshes')
ListRoutes = Action('ListRoutes')
ListTagsForResource = Action('ListTagsForResource')
ListVirtualGateways = Action('ListVirtualGateways')
ListVirtualNodes = Action('ListVirtualNodes')
ListVirtualRouters = Action('ListVirtualRouters')
ListVirtualServices = Action('ListVirtualServices')
StreamAggregatedResources = Action('StreamAggregatedResources')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateGatewayRoute = Action('UpdateGatewayRoute')
UpdateMesh = Action('UpdateMesh')
UpdateRoute = Action('UpdateRoute')
UpdateVirtualGateway = Action('UpdateVirtualGateway')
UpdateVirtualNode = Action('UpdateVirtualNode')
UpdateVirtualRouter = Action('UpdateVirtualRouter')
UpdateVirtualService = Action('UpdateVirtualService')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Resource Groups'
prefix = 'resource-groups'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateGroup = Action('CreateGroup')
DeleteGroup = Action('DeleteGroup')
GetGroup = Action('GetGroup')
GetGroupQuery = Action('GetGroupQuery')
GetTags = Action('GetTags')
ListGroupResources = Action('ListGroupResources')
ListGroups = Action('ListGroups')
SearchResources = Action('SearchResources')
Tag = Action('Tag')
Untag = Action('Untag')
UpdateGroup = Action('UpdateGroup')
UpdateGroupQuery = Action('UpdateGroupQuery')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeArtifact'
prefix = 'codeartifact'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateExternalConnection = Action('AssociateExternalConnection')
AssociateWithDownstreamRepository = \
    Action('AssociateWithDownstreamRepository')
CopyPackageVersions = Action('CopyPackageVersions')
CreateDomain = Action('CreateDomain')
CreateRepository = Action('CreateRepository')
DeleteDomain = Action('DeleteDomain')
DeleteDomainPermissionsPolicy = Action('DeleteDomainPermissionsPolicy')
DeletePackageVersions = Action('DeletePackageVersions')
DeleteRepository = Action('DeleteRepository')
DeleteRepositoryPermissionsPolicy = \
    Action('DeleteRepositoryPermissionsPolicy')
DescribeDomain = Action('DescribeDomain')
DescribePackageVersion = Action('DescribePackageVersion')
DescribeRepository = Action('DescribeRepository')
DisassociateExternalConnection = Action('DisassociateExternalConnection')
DisposePackageVersions = Action('DisposePackageVersions')
GetAuthorizationToken = Action('GetAuthorizationToken')
GetDomainPermissionsPolicy = Action('GetDomainPermissionsPolicy')
GetPackageVersionAsset = Action('GetPackageVersionAsset')
GetPackageVersionReadme = Action('GetPackageVersionReadme')
GetRepositoryEndpoint = Action('GetRepositoryEndpoint')
GetRepositoryPermissionsPolicy = Action('GetRepositoryPermissionsPolicy')
ListDomains = Action('ListDomains')
ListPackageVersionAssets = Action('ListPackageVersionAssets')
ListPackageVersionDependencies = Action('ListPackageVersionDependencies')
ListPackageVersions = Action('ListPackageVersions')
ListPackages = Action('ListPackages')
ListRepositories = Action('ListRepositories')
ListRepositoriesInDomain = Action('ListRepositoriesInDomain')
PublishPackageVersion = Action('PublishPackageVersion')
PutDomainPermissionsPolicy = Action('PutDomainPermissionsPolicy')
PutPackageMetadata = Action('PutPackageMetadata')
PutRepositoryPermissionsPolicy = Action('PutRepositoryPermissionsPolicy')
ReadFromRepository = Action('ReadFromRepository')
UpdatePackageVersionsStatus = Action('UpdatePackageVersionsStatus')
UpdateRepository = Action('UpdateRepository')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Health APIs and Notifications'
prefix = 'health'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DescribeAffectedAccountsForOrganization = \
    Action('DescribeAffectedAccountsForOrganization')
DescribeAffectedEntities = Action('DescribeAffectedEntities')
DescribeAffectedEntitiesForOrganization = \
    Action('DescribeAffectedEntitiesForOrganization')
DescribeEntityAggregates = Action('DescribeEntityAggregates')
DescribeEventAggregates = Action('DescribeEventAggregates')
DescribeEventDetails = Action('DescribeEventDetails')
DescribeEventDetailsForOrganization = \
    Action('DescribeEventDetailsForOrganization')
DescribeEventTypes = Action('DescribeEventTypes')
DescribeEvents = Action('DescribeEvents')
DescribeEventsForOrganization = Action('DescribeEventsForOrganization')
DescribeHealthServiceStatusForOrganization = \
    Action('DescribeHealthServiceStatusForOrganization')
DisableHealthServiceAccessForOrganization = \
    Action('DisableHealthServiceAccessForOrganization')
EnableHealthServiceAccessForOrganization = \
    Action('EnableHealthServiceAccessForOrganization')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Shield'
prefix = 'shield'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateDRTLogBucket = Action('AssociateDRTLogBucket')
AssociateDRTRole = Action('AssociateDRTRole')
CreateProtection = Action('CreateProtection')
CreateSubscription = Action('CreateSubscription')
DeleteProtection = Action('DeleteProtection')
DeleteSubscription = Action('DeleteSubscription')
DescribeAttack = Action('DescribeAttack')
DescribeDRTAccess = Action('DescribeDRTAccess')
DescribeEmergencyContactSettings = \
    Action('DescribeEmergencyContactSettings')
DescribeProtection = Action('DescribeProtection')
DescribeSubscription = Action('DescribeSubscription')
DisassociateDRTLogBucket = Action('DisassociateDRTLogBucket')
DisassociateDRTRole = Action('DisassociateDRTRole')
GetSubscriptionState = Action('GetSubscriptionState')
ListAttacks = Action('ListAttacks')
ListProtections = Action('ListProtections')
UpdateEmergencyContactSettings = Action('UpdateEmergencyContactSettings')
UpdateSubscription = Action('UpdateSubscription')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Cost Explorer Service'
prefix = 'ce'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateAnomalyMonitor = Action('CreateAnomalyMonitor')
CreateAnomalySubscription = Action('CreateAnomalySubscription')
CreateCostCategoryDefinition = Action('CreateCostCategoryDefinition')
DeleteAnomalyMonitor = Action('DeleteAnomalyMonitor')
DeleteAnomalySubscription = Action('DeleteAnomalySubscription')
DeleteCostCategoryDefinition = Action('DeleteCostCategoryDefinition')
DescribeCostCategoryDefinition = Action('DescribeCostCategoryDefinition')
GetAnomalies = Action('GetAnomalies')
GetAnomalyMonitors = Action('GetAnomalyMonitors')
GetAnomalySubscriptions = Action('GetAnomalySubscriptions')
GetCostAndUsage = Action('GetCostAndUsage')
GetCostAndUsageWithResources = Action('GetCostAndUsageWithResources')
GetCostForecast = Action('GetCostForecast')
GetDimensionValues = Action('GetDimensionValues')
GetReservationCoverage = Action('GetReservationCoverage')
GetReservationPurchaseRecommendation = \
    Action('GetReservationPurchaseRecommendation')
GetReservationUtilization = Action('GetReservationUtilization')
GetRightsizingRecommendation = Action('GetRightsizingRecommendation')
GetSavingsPlansCoverage = Action('GetSavingsPlansCoverage')
GetSavingsPlansPurchaseRecommendation = \
    Action('GetSavingsPlansPurchaseRecommendation')
GetSavingsPlansUtilization = Action('GetSavingsPlansUtilization')
GetSavingsPlansUtilizationDetails = \
    Action('GetSavingsPlansUtilizationDetails')
GetTags = Action('GetTags')
GetUsageForecast = Action('GetUsageForecast')
ListCostCategoryDefinitions = Action('ListCostCategoryDefinitions')
ProvideAnomalyFeedback = Action('ProvideAnomalyFeedback')
UpdateAnomalyMonitor = Action('UpdateAnomalyMonitor')
UpdateAnomalySubscription = Action('UpdateAnomalySubscription')
UpdateCostCategoryDefinition = Action('UpdateCostCategoryDefinition')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Simple Systems Manager'
prefix = 'ssm'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTagsToResource = Action('AddTagsToResource')
CancelCommand = Action('CancelCommand')
CancelMaintenanceWindowExecution = \
    Action('CancelMaintenanceWindowExecution')
CreateActivation = Action('CreateActivation')
CreateAssociation = Action('CreateAssociation')
CreateAssociationBatch = Action('CreateAssociationBatch')
CreateDocument = Action('CreateDocument')
CreateMaintenanceWindow = Action('CreateMaintenanceWindow')
CreateOpsItem = Action('CreateOpsItem')
CreatePatchBaseline = Action('CreatePatchBaseline')
CreateResourceDataSync = Action('CreateResourceDataSync')
DeleteActivation = Action('DeleteActivation')
DeleteAssociation = Action('DeleteAssociation')
DeleteDocument = Action('DeleteDocument')
DeleteInventory = Action('DeleteInventory')
DeleteMaintenanceWindow = Action('DeleteMaintenanceWindow')
DeleteParameter = Action('DeleteParameter')
DeleteParameters = Action('DeleteParameters')
DeletePatchBaseline = Action('DeletePatchBaseline')
DeleteResourceDataSync = Action('DeleteResourceDataSync')
DeregisterManagedInstance = Action('DeregisterManagedInstance')
DeregisterPatchBaselineForPatchGroup = \
    Action('DeregisterPatchBaselineForPatchGroup')
DeregisterTargetFromMaintenanceWindow = \
    Action('DeregisterTargetFromMaintenanceWindow')
DeregisterTaskFromMaintenanceWindow = \
    Action('DeregisterTaskFromMaintenanceWindow')
DescribeActivations = Action('DescribeActivations')
DescribeAssociation = Action('DescribeAssociation')
DescribeAssociationExecutionTargets = \
    Action('DescribeAssociationExecutionTargets')
DescribeAssociationExecutions = Action('DescribeAssociationExecutions')
DescribeAutomationExecutions = Action('DescribeAutomationExecutions')
DescribeAutomationStepExecutions = \
    Action('DescribeAutomationStepExecutions')
DescribeAvailablePatches = Action('DescribeAvailablePatches')
DescribeDocument = Action('DescribeDocument')
DescribeDocumentParameters = Action('DescribeDocumentParameters')
DescribeDocumentPermission = Action('DescribeDocumentPermission')
DescribeEffectiveInstanceAssociations = \
    Action('DescribeEffectiveInstanceAssociations')
DescribeEffectivePatchesForPatchBaseline = \
    Action('DescribeEffectivePatchesForPatchBaseline')
DescribeInstanceAssociationsStatus = \
    Action('DescribeInstanceAssociationsStatus')
DescribeInstanceInformation = Action('DescribeInstanceInformation')
DescribeInstancePatchStates = Action('DescribeInstancePatchStates')
DescribeInstancePatchStatesForPatchGroup = \
    Action('DescribeInstancePatchStatesForPatchGroup')
DescribeInstancePatches = Action('DescribeInstancePatches')
DescribeInstanceProperties = Action('DescribeInstanceProperties')
DescribeInventoryDeletions = Action('DescribeInventoryDeletions')
DescribeMaintenanceWindowExecutionTaskInvocations = \
    Action('DescribeMaintenanceWindowExecutionTaskInvocations')
DescribeMaintenanceWindowExecutionTasks = \
    Action('DescribeMaintenanceWindowExecutionTasks')
DescribeMaintenanceWindowExecutions = \
    Action('DescribeMaintenanceWindowExecutions')
DescribeMaintenanceWindowSchedule = \
    Action('DescribeMaintenanceWindowSchedule')
DescribeMaintenanceWindowTargets = \
    Action('DescribeMaintenanceWindowTargets')
DescribeMaintenanceWindowTasks = Action('DescribeMaintenanceWindowTasks')
DescribeMaintenanceWindows = Action('DescribeMaintenanceWindows')
DescribeMaintenanceWindowsForTarget = \
    Action('DescribeMaintenanceWindowsForTarget')
DescribeOpsItems = Action('DescribeOpsItems')
DescribeParameters = Action('DescribeParameters')
DescribePatchBaselines = Action('DescribePatchBaselines')
DescribePatchGroupState = Action('DescribePatchGroupState')
DescribePatchGroups = Action('DescribePatchGroups')
DescribePatchProperties = Action('DescribePatchProperties')
DescribeSessions = Action('DescribeSessions')
GetAutomationExecution = Action('GetAutomationExecution')
GetCommandInvocation = Action('GetCommandInvocation')
GetConnectionStatus = Action('GetConnectionStatus')
GetDefaultPatchBaseline = Action('GetDefaultPatchBaseline')
GetDeployablePatchSnapshotForInstance = \
    Action('GetDeployablePatchSnapshotForInstance')
GetDocument = Action('GetDocument')
GetInventory = Action('GetInventory')
GetInventorySchema = Action('GetInventorySchema')
GetMaintenanceWindow = Action('GetMaintenanceWindow')
GetMaintenanceWindowExecution = Action('GetMaintenanceWindowExecution')
GetMaintenanceWindowExecutionTask = \
    Action('GetMaintenanceWindowExecutionTask')
GetMaintenanceWindowExecutionTaskInvocation = \
    Action('GetMaintenanceWindowExecutionTaskInvocation')
GetMaintenanceWindowTask = Action('GetMaintenanceWindowTask')
GetManifest = Action('GetManifest')
GetOpsItem = Action('GetOpsItem')
GetOpsSummary = Action('GetOpsSummary')
GetParameter = Action('GetParameter')
GetParameterHistory = Action('GetParameterHistory')
GetParameters = Action('GetParameters')
GetParametersByPath = Action('GetParametersByPath')
GetPatchBaseline = Action('GetPatchBaseline')
GetPatchBaselineForPatchGroup = Action('GetPatchBaselineForPatchGroup')
GetServiceSetting = Action('GetServiceSetting')
LabelParameterVersion = Action('LabelParameterVersion')
ListAssociationVersions = Action('ListAssociationVersions')
ListAssociations = Action('ListAssociations')
ListCommandInvocations = Action('ListCommandInvocations')
ListCommands = Action('ListCommands')
ListComplianceItems = Action('ListComplianceItems')
ListComplianceSummaries = Action('ListComplianceSummaries')
ListDocumentVersions = Action('ListDocumentVersions')
ListDocuments = Action('ListDocuments')
ListInstanceAssociations = Action('ListInstanceAssociations')
ListInventoryEntries = Action('ListInventoryEntries')
ListResourceComplianceSummaries = \
    Action('ListResourceComplianceSummaries')
ListResourceDataSync = Action('ListResourceDataSync')
ListTagsForResource = Action('ListTagsForResource')
ModifyDocumentPermission = Action('ModifyDocumentPermission')
PutComplianceItems = Action('PutComplianceItems')
PutConfigurePackageResult = Action('PutConfigurePackageResult')
PutInventory = Action('PutInventory')
PutParameter = Action('PutParameter')
RegisterDefaultPatchBaseline = Action('RegisterDefaultPatchBaseline')
RegisterPatchBaselineForPatchGroup = \
    Action('RegisterPatchBaselineForPatchGroup')
RegisterTargetWithMaintenanceWindow = \
    Action('RegisterTargetWithMaintenanceWindow')
RegisterTaskWithMaintenanceWindow = \
    Action('RegisterTaskWithMaintenanceWindow')
RemoveTagsFromResource = Action('RemoveTagsFromResource')
ResetServiceSetting = Action('ResetServiceSetting')
ResumeSession = Action('ResumeSession')
SendAutomationSignal = Action('SendAutomationSignal')
SendCommand = Action('SendCommand')
StartAssociationsOnce = Action('StartAssociationsOnce')
StartAutomationExecution = Action('StartAutomationExecution')
StartSession = Action('StartSession')
StopAutomationExecution = Action('StopAutomationExecution')
TerminateSession = Action('TerminateSession')
UpdateAssociation = Action('UpdateAssociation')
UpdateAssociationStatus = Action('UpdateAssociationStatus')
UpdateDocument = Action('UpdateDocument')
UpdateDocumentDefaultVersion = Action('UpdateDocumentDefaultVersion')
UpdateInstanceAssociationStatus = \
    Action('UpdateInstanceAssociationStatus')
UpdateInstanceInformation = Action('UpdateInstanceInformation')
UpdateMaintenanceWindow = Action('UpdateMaintenanceWindow')
UpdateMaintenanceWindowTarget = Action('UpdateMaintenanceWindowTarget')
UpdateMaintenanceWindowTask = Action('UpdateMaintenanceWindowTask')
UpdateManagedInstanceRole = Action('UpdateManagedInstanceRole')
UpdateOpsItem = Action('UpdateOpsItem')
UpdatePatchBaseline = Action('UpdatePatchBaseline')
UpdateResourceDataSync = Action('UpdateResourceDataSync')
UpdateServiceSetting = Action('UpdateServiceSetting')



from awacs.aws import Action, Allow, Policy, Statement


pd = Policy(
    Statement=[
        Statement(
            Effect=Allow,
            Action=[Action("sdb", "*"), Action("s3", "*")],
            Resource=["arn:aws:s3:::my_corporate_bucket/*"],
        ),
    ],
)
print(pd.to_json())



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Route 53 Resolver'
prefix = 'route53resolver'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateResolverEndpointIpAddress = \
    Action('AssociateResolverEndpointIpAddress')
AssociateResolverQueryLogConfig = \
    Action('AssociateResolverQueryLogConfig')
AssociateResolverRule = Action('AssociateResolverRule')
CreateResolverEndpoint = Action('CreateResolverEndpoint')
CreateResolverQueryLogConfig = Action('CreateResolverQueryLogConfig')
CreateResolverRule = Action('CreateResolverRule')
DeleteResolverEndpoint = Action('DeleteResolverEndpoint')
DeleteResolverQueryLogConfig = Action('DeleteResolverQueryLogConfig')
DeleteResolverRule = Action('DeleteResolverRule')
DisassociateResolverEndpointIpAddress = \
    Action('DisassociateResolverEndpointIpAddress')
DisassociateResolverQueryLogConfig = \
    Action('DisassociateResolverQueryLogConfig')
DisassociateResolverRule = Action('DisassociateResolverRule')
GetResolverEndpoint = Action('GetResolverEndpoint')
GetResolverQueryLogConfig = Action('GetResolverQueryLogConfig')
GetResolverQueryLogConfigAssociation = \
    Action('GetResolverQueryLogConfigAssociation')
GetResolverQueryLogConfigPolicy = \
    Action('GetResolverQueryLogConfigPolicy')
GetResolverRule = Action('GetResolverRule')
GetResolverRuleAssociation = Action('GetResolverRuleAssociation')
GetResolverRulePolicy = Action('GetResolverRulePolicy')
ListResolverEndpointIpAddresses = \
    Action('ListResolverEndpointIpAddresses')
ListResolverEndpoints = Action('ListResolverEndpoints')
ListResolverQueryLogConfigAssociations = \
    Action('ListResolverQueryLogConfigAssociations')
ListResolverQueryLogConfigs = Action('ListResolverQueryLogConfigs')
ListResolverRuleAssociations = Action('ListResolverRuleAssociations')
ListResolverRules = Action('ListResolverRules')
ListTagsForResource = Action('ListTagsForResource')
PutResolverQueryLogConfigPolicy = \
    Action('PutResolverQueryLogConfigPolicy')
PutResolverRulePolicy = Action('PutResolverRulePolicy')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateResolverEndpoint = Action('UpdateResolverEndpoint')
UpdateResolverRule = Action('UpdateResolverRule')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT'
prefix = 'iot'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptCertificateTransfer = Action('AcceptCertificateTransfer')
AddThingToBillingGroup = Action('AddThingToBillingGroup')
AddThingToThingGroup = Action('AddThingToThingGroup')
AssociateTargetsWithJob = Action('AssociateTargetsWithJob')
AttachPolicy = Action('AttachPolicy')
AttachPrincipalPolicy = Action('AttachPrincipalPolicy')
AttachSecurityProfile = Action('AttachSecurityProfile')
AttachThingPrincipal = Action('AttachThingPrincipal')
CancelAuditMitigationActionsTask = \
    Action('CancelAuditMitigationActionsTask')
CancelAuditTask = Action('CancelAuditTask')
CancelCertificateTransfer = Action('CancelCertificateTransfer')
CancelJob = Action('CancelJob')
CancelJobExecution = Action('CancelJobExecution')
ClearDefaultAuthorizer = Action('ClearDefaultAuthorizer')
CloseTunnel = Action('CloseTunnel')
Connect = Action('Connect')
CreateAuditSuppression = Action('CreateAuditSuppression')
CreateAuthorizer = Action('CreateAuthorizer')
CreateBillingGroup = Action('CreateBillingGroup')
CreateCertificateFromCsr = Action('CreateCertificateFromCsr')
CreateDimension = Action('CreateDimension')
CreateDomainConfiguration = Action('CreateDomainConfiguration')
CreateDynamicThingGroup = Action('CreateDynamicThingGroup')
CreateJob = Action('CreateJob')
CreateKeysAndCertificate = Action('CreateKeysAndCertificate')
CreateMitigationAction = Action('CreateMitigationAction')
CreateOTAUpdate = Action('CreateOTAUpdate')
CreateOTAUpdateJob = Action('CreateOTAUpdateJob')
CreatePolicy = Action('CreatePolicy')
CreatePolicyVersion = Action('CreatePolicyVersion')
CreateProvisioningClaim = Action('CreateProvisioningClaim')
CreateProvisioningTemplate = Action('CreateProvisioningTemplate')
CreateProvisioningTemplateVersion = \
    Action('CreateProvisioningTemplateVersion')
CreateRoleAlias = Action('CreateRoleAlias')
CreateScheduledAudit = Action('CreateScheduledAudit')
CreateSecurityProfile = Action('CreateSecurityProfile')
CreateStream = Action('CreateStream')
CreateThing = Action('CreateThing')
CreateThingGroup = Action('CreateThingGroup')
CreateThingType = Action('CreateThingType')
CreateTopicRule = Action('CreateTopicRule')
DeleteAccountAuditConfiguration = \
    Action('DeleteAccountAuditConfiguration')
DeleteAuditSuppression = Action('DeleteAuditSuppression')
DeleteAuthorizer = Action('DeleteAuthorizer')
DeleteBillingGroup = Action('DeleteBillingGroup')
DeleteCACertificate = Action('DeleteCACertificate')
DeleteCertificate = Action('DeleteCertificate')
DeleteDimension = Action('DeleteDimension')
DeleteDomainConfiguration = Action('DeleteDomainConfiguration')
DeleteDynamicThingGroup = Action('DeleteDynamicThingGroup')
DeleteJob = Action('DeleteJob')
DeleteJobExecution = Action('DeleteJobExecution')
DeleteMitigationAction = Action('DeleteMitigationAction')
DeleteOTAUpdate = Action('DeleteOTAUpdate')
DeleteOTAUpdateJob = Action('DeleteOTAUpdateJob')
DeletePolicy = Action('DeletePolicy')
DeletePolicyVersion = Action('DeletePolicyVersion')
DeleteProvisioningTemplate = Action('DeleteProvisioningTemplate')
DeleteProvisioningTemplateVersion = \
    Action('DeleteProvisioningTemplateVersion')
DeleteRegistrationCode = Action('DeleteRegistrationCode')
DeleteRoleAlias = Action('DeleteRoleAlias')
DeleteScheduledAudit = Action('DeleteScheduledAudit')
DeleteSecurityProfile = Action('DeleteSecurityProfile')
DeleteStream = Action('DeleteStream')
DeleteThing = Action('DeleteThing')
DeleteThingGroup = Action('DeleteThingGroup')
DeleteThingShadow = Action('DeleteThingShadow')
DeleteThingType = Action('DeleteThingType')
DeleteTopicRule = Action('DeleteTopicRule')
DeleteV2LoggingLevel = Action('DeleteV2LoggingLevel')
DeprecateThingType = Action('DeprecateThingType')
DescribeAccountAuditConfiguration = \
    Action('DescribeAccountAuditConfiguration')
DescribeAuditFinding = Action('DescribeAuditFinding')
DescribeAuditMitigationActionsTask = \
    Action('DescribeAuditMitigationActionsTask')
DescribeAuditSuppression = Action('DescribeAuditSuppression')
DescribeAuditTask = Action('DescribeAuditTask')
DescribeAuthorizer = Action('DescribeAuthorizer')
DescribeBillingGroup = Action('DescribeBillingGroup')
DescribeCACertificate = Action('DescribeCACertificate')
DescribeCertificate = Action('DescribeCertificate')
DescribeDefaultAuthorizer = Action('DescribeDefaultAuthorizer')
DescribeDimension = Action('DescribeDimension')
DescribeDomainConfiguration = Action('DescribeDomainConfiguration')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeEventConfigurations = Action('DescribeEventConfigurations')
DescribeIndex = Action('DescribeIndex')
DescribeJob = Action('DescribeJob')
DescribeJobExecution = Action('DescribeJobExecution')
DescribeMitigationAction = Action('DescribeMitigationAction')
DescribeProvisioningTemplate = Action('DescribeProvisioningTemplate')
DescribeProvisioningTemplateVersion = \
    Action('DescribeProvisioningTemplateVersion')
DescribeRoleAlias = Action('DescribeRoleAlias')
DescribeScheduledAudit = Action('DescribeScheduledAudit')
DescribeSecurityProfile = Action('DescribeSecurityProfile')
DescribeStream = Action('DescribeStream')
DescribeThing = Action('DescribeThing')
DescribeThingGroup = Action('DescribeThingGroup')
DescribeThingRegistrationTask = Action('DescribeThingRegistrationTask')
DescribeThingType = Action('DescribeThingType')
DescribeTunnel = Action('DescribeTunnel')
DetachPolicy = Action('DetachPolicy')
DetachPrincipalPolicy = Action('DetachPrincipalPolicy')
DetachSecurityProfile = Action('DetachSecurityProfile')
DetachThingPrincipal = Action('DetachThingPrincipal')
DisableTopicRule = Action('DisableTopicRule')
EnableTopicRule = Action('EnableTopicRule')
GetCardinality = Action('GetCardinality')
GetEffectivePolicies = Action('GetEffectivePolicies')
GetIndexingConfiguration = Action('GetIndexingConfiguration')
GetJobDocument = Action('GetJobDocument')
GetLoggingOptions = Action('GetLoggingOptions')
GetOTAUpdate = Action('GetOTAUpdate')
GetOTAUpdateJob = Action('GetOTAUpdateJob')
GetPendingJobExecutions = Action('GetPendingJobExecutions')
GetPercentiles = Action('GetPercentiles')
GetPolicy = Action('GetPolicy')
GetPolicyVersion = Action('GetPolicyVersion')
GetRegistrationCode = Action('GetRegistrationCode')
GetStatistics = Action('GetStatistics')
GetThingShadow = Action('GetThingShadow')
GetTopicRule = Action('GetTopicRule')
GetV2LoggingOptions = Action('GetV2LoggingOptions')
ListActiveViolations = Action('ListActiveViolations')
ListAttachedPolicies = Action('ListAttachedPolicies')
ListAuditFindings = Action('ListAuditFindings')
ListAuditMitigationActionsExecutions = \
    Action('ListAuditMitigationActionsExecutions')
ListAuditMitigationActionsTasks = \
    Action('ListAuditMitigationActionsTasks')
ListAuditSuppressions = Action('ListAuditSuppressions')
ListAuditTasks = Action('ListAuditTasks')
ListAuthorizers = Action('ListAuthorizers')
ListBillingGroups = Action('ListBillingGroups')
ListCACertificates = Action('ListCACertificates')
ListCertificates = Action('ListCertificates')
ListCertificatesByCA = Action('ListCertificatesByCA')
ListDimensions = Action('ListDimensions')
ListDomainConfigurations = Action('ListDomainConfigurations')
ListIndices = Action('ListIndices')
ListJobExecutionsForJob = Action('ListJobExecutionsForJob')
ListJobExecutionsForThing = Action('ListJobExecutionsForThing')
ListJobs = Action('ListJobs')
ListMitigationActions = Action('ListMitigationActions')
ListNamedShadowsForThing = Action('ListNamedShadowsForThing')
ListOTAUpdateJobs = Action('ListOTAUpdateJobs')
ListOTAUpdates = Action('ListOTAUpdates')
ListOutgoingCertificates = Action('ListOutgoingCertificates')
ListPolicies = Action('ListPolicies')
ListPolicyPrincipals = Action('ListPolicyPrincipals')
ListPolicyVersions = Action('ListPolicyVersions')
ListPrincipalPolicies = Action('ListPrincipalPolicies')
ListPrincipalThings = Action('ListPrincipalThings')
ListProvisioningTemplateVersions = \
    Action('ListProvisioningTemplateVersions')
ListProvisioningTemplates = Action('ListProvisioningTemplates')
ListRoleAliases = Action('ListRoleAliases')
ListScheduledAudits = Action('ListScheduledAudits')
ListSecurityProfiles = Action('ListSecurityProfiles')
ListSecurityProfilesForTarget = Action('ListSecurityProfilesForTarget')
ListStreams = Action('ListStreams')
ListTagsForResource = Action('ListTagsForResource')
ListTargetsForPolicy = Action('ListTargetsForPolicy')
ListTargetsForSecurityProfile = Action('ListTargetsForSecurityProfile')
ListThingGroups = Action('ListThingGroups')
ListThingGroupsForThing = Action('ListThingGroupsForThing')
ListThingPrincipals = Action('ListThingPrincipals')
ListThingRegistrationTaskReports = \
    Action('ListThingRegistrationTaskReports')
ListThingRegistrationTasks = Action('ListThingRegistrationTasks')
ListThingTypes = Action('ListThingTypes')
ListThings = Action('ListThings')
ListThingsInBillingGroup = Action('ListThingsInBillingGroup')
ListThingsInThingGroup = Action('ListThingsInThingGroup')
ListTopicRules = Action('ListTopicRules')
ListTunnels = Action('ListTunnels')
ListV2LoggingLevels = Action('ListV2LoggingLevels')
ListViolationEvents = Action('ListViolationEvents')
OpenTunnel = Action('OpenTunnel')
Publish = Action('Publish')
Receive = Action('Receive')
RegisterCACertificate = Action('RegisterCACertificate')
RegisterCertificate = Action('RegisterCertificate')
RegisterCertificateWithoutCA = Action('RegisterCertificateWithoutCA')
RegisterThing = Action('RegisterThing')
RejectCertificateTransfer = Action('RejectCertificateTransfer')
RemoveThingFromBillingGroup = Action('RemoveThingFromBillingGroup')
RemoveThingFromThingGroup = Action('RemoveThingFromThingGroup')
ReplaceTopicRule = Action('ReplaceTopicRule')
SearchIndex = Action('SearchIndex')
SetDefaultAuthorizer = Action('SetDefaultAuthorizer')
SetDefaultPolicyVersion = Action('SetDefaultPolicyVersion')
SetLoggingOptions = Action('SetLoggingOptions')
SetV2LoggingLevel = Action('SetV2LoggingLevel')
SetV2LoggingOptions = Action('SetV2LoggingOptions')
StartAuditMitigationActionsTask = \
    Action('StartAuditMitigationActionsTask')
StartNextPendingJobExecution = Action('StartNextPendingJobExecution')
StartOnDemandAuditTask = Action('StartOnDemandAuditTask')
StartThingRegistrationTask = Action('StartThingRegistrationTask')
StopThingRegistrationTask = Action('StopThingRegistrationTask')
Subscribe = Action('Subscribe')
TagResource = Action('TagResource')
TestAuthorization = Action('TestAuthorization')
TestInvokeAuthorizer = Action('TestInvokeAuthorizer')
TransferCertificate = Action('TransferCertificate')
UntagResource = Action('UntagResource')
UpdateAccountAuditConfiguration = \
    Action('UpdateAccountAuditConfiguration')
UpdateAuditSuppression = Action('UpdateAuditSuppression')
UpdateAuthorizer = Action('UpdateAuthorizer')
UpdateBillingGroup = Action('UpdateBillingGroup')
UpdateCACertificate = Action('UpdateCACertificate')
UpdateCertificate = Action('UpdateCertificate')
UpdateDimension = Action('UpdateDimension')
UpdateDomainConfiguration = Action('UpdateDomainConfiguration')
UpdateDynamicThingGroup = Action('UpdateDynamicThingGroup')
UpdateEventConfigurations = Action('UpdateEventConfigurations')
UpdateIndexingConfiguration = Action('UpdateIndexingConfiguration')
UpdateJob = Action('UpdateJob')
UpdateJobExecution = Action('UpdateJobExecution')
UpdateMitigationAction = Action('UpdateMitigationAction')
UpdateProvisioningTemplate = Action('UpdateProvisioningTemplate')
UpdateRoleAlias = Action('UpdateRoleAlias')
UpdateScheduledAudit = Action('UpdateScheduledAudit')
UpdateSecurityProfile = Action('UpdateSecurityProfile')
UpdateStream = Action('UpdateStream')
UpdateThing = Action('UpdateThing')
UpdateThingGroup = Action('UpdateThingGroup')
UpdateThingGroupsForThing = Action('UpdateThingGroupsForThing')
UpdateThingShadow = Action('UpdateThingShadow')
ValidateSecurityProfileBehaviors = \
    Action('ValidateSecurityProfileBehaviors')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Redshift'
prefix = 'redshift'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptReservedNodeExchange = Action('AcceptReservedNodeExchange')
AuthorizeClusterSecurityGroupIngress = \
    Action('AuthorizeClusterSecurityGroupIngress')
AuthorizeSnapshotAccess = Action('AuthorizeSnapshotAccess')
BatchDeleteClusterSnapshots = Action('BatchDeleteClusterSnapshots')
BatchModifyClusterSnapshots = Action('BatchModifyClusterSnapshots')
CancelQuery = Action('CancelQuery')
CancelQuerySession = Action('CancelQuerySession')
CancelResize = Action('CancelResize')
CopyClusterSnapshot = Action('CopyClusterSnapshot')
CreateCluster = Action('CreateCluster')
CreateClusterParameterGroup = Action('CreateClusterParameterGroup')
CreateClusterSecurityGroup = Action('CreateClusterSecurityGroup')
CreateClusterSnapshot = Action('CreateClusterSnapshot')
CreateClusterSubnetGroup = Action('CreateClusterSubnetGroup')
CreateClusterUser = Action('CreateClusterUser')
CreateEventSubscription = Action('CreateEventSubscription')
CreateHsmClientCertificate = Action('CreateHsmClientCertificate')
CreateHsmConfiguration = Action('CreateHsmConfiguration')
CreateSavedQuery = Action('CreateSavedQuery')
CreateScheduledAction = Action('CreateScheduledAction')
CreateSnapshotCopyGrant = Action('CreateSnapshotCopyGrant')
CreateSnapshotSchedule = Action('CreateSnapshotSchedule')
CreateTags = Action('CreateTags')
DeleteCluster = Action('DeleteCluster')
DeleteClusterParameterGroup = Action('DeleteClusterParameterGroup')
DeleteClusterSecurityGroup = Action('DeleteClusterSecurityGroup')
DeleteClusterSnapshot = Action('DeleteClusterSnapshot')
DeleteClusterSubnetGroup = Action('DeleteClusterSubnetGroup')
DeleteEventSubscription = Action('DeleteEventSubscription')
DeleteHsmClientCertificate = Action('DeleteHsmClientCertificate')
DeleteHsmConfiguration = Action('DeleteHsmConfiguration')
DeleteSavedQueries = Action('DeleteSavedQueries')
DeleteScheduledAction = Action('DeleteScheduledAction')
DeleteSnapshotCopyGrant = Action('DeleteSnapshotCopyGrant')
DeleteSnapshotSchedule = Action('DeleteSnapshotSchedule')
DeleteTags = Action('DeleteTags')
DescribeAccountAttributes = Action('DescribeAccountAttributes')
DescribeClusterDbRevisions = Action('DescribeClusterDbRevisions')
DescribeClusterParameterGroups = Action('DescribeClusterParameterGroups')
DescribeClusterParameters = Action('DescribeClusterParameters')
DescribeClusterSecurityGroups = Action('DescribeClusterSecurityGroups')
DescribeClusterSnapshots = Action('DescribeClusterSnapshots')
DescribeClusterSubnetGroups = Action('DescribeClusterSubnetGroups')
DescribeClusterTracks = Action('DescribeClusterTracks')
DescribeClusterVersions = Action('DescribeClusterVersions')
DescribeClusters = Action('DescribeClusters')
DescribeDefaultClusterParameters = \
    Action('DescribeDefaultClusterParameters')
DescribeEventCategories = Action('DescribeEventCategories')
DescribeEventSubscriptions = Action('DescribeEventSubscriptions')
DescribeEvents = Action('DescribeEvents')
DescribeHsmClientCertificates = Action('DescribeHsmClientCertificates')
DescribeHsmConfigurations = Action('DescribeHsmConfigurations')
DescribeLoggingStatus = Action('DescribeLoggingStatus')
DescribeNodeConfigurationOptions = \
    Action('DescribeNodeConfigurationOptions')
DescribeOrderableClusterOptions = \
    Action('DescribeOrderableClusterOptions')
DescribeQuery = Action('DescribeQuery')
DescribeReservedNodeOfferings = Action('DescribeReservedNodeOfferings')
DescribeReservedNodes = Action('DescribeReservedNodes')
DescribeResize = Action('DescribeResize')
DescribeSavedQueries = Action('DescribeSavedQueries')
DescribeScheduledActions = Action('DescribeScheduledActions')
DescribeSnapshotCopyGrants = Action('DescribeSnapshotCopyGrants')
DescribeSnapshotSchedules = Action('DescribeSnapshotSchedules')
DescribeStorage = Action('DescribeStorage')
DescribeTable = Action('DescribeTable')
DescribeTableRestoreStatus = Action('DescribeTableRestoreStatus')
DescribeTags = Action('DescribeTags')
DisableLogging = Action('DisableLogging')
DisableSnapshotCopy = Action('DisableSnapshotCopy')
EnableLogging = Action('EnableLogging')
EnableSnapshotCopy = Action('EnableSnapshotCopy')
ExecuteQuery = Action('ExecuteQuery')
FetchResults = Action('FetchResults')
GetClusterCredentials = Action('GetClusterCredentials')
GetReservedNodeExchangeOfferings = \
    Action('GetReservedNodeExchangeOfferings')
JoinGroup = Action('JoinGroup')
ListDatabases = Action('ListDatabases')
ListSavedQueries = Action('ListSavedQueries')
ListSchemas = Action('ListSchemas')
ListTables = Action('ListTables')
ModifyCluster = Action('ModifyCluster')
ModifyClusterDbRevision = Action('ModifyClusterDbRevision')
ModifyClusterIamRoles = Action('ModifyClusterIamRoles')
ModifyClusterMaintenance = Action('ModifyClusterMaintenance')
ModifyClusterParameterGroup = Action('ModifyClusterParameterGroup')
ModifyClusterSnapshot = Action('ModifyClusterSnapshot')
ModifyClusterSnapshotSchedule = Action('ModifyClusterSnapshotSchedule')
ModifyClusterSubnetGroup = Action('ModifyClusterSubnetGroup')
ModifyEventSubscription = Action('ModifyEventSubscription')
ModifySavedQuery = Action('ModifySavedQuery')
ModifyScheduledAction = Action('ModifyScheduledAction')
ModifySnapshotCopyRetentionPeriod = \
    Action('ModifySnapshotCopyRetentionPeriod')
ModifySnapshotSchedule = Action('ModifySnapshotSchedule')
PauseCluster = Action('PauseCluster')
PurchaseReservedNodeOffering = Action('PurchaseReservedNodeOffering')
RebootCluster = Action('RebootCluster')
ResetClusterParameterGroup = Action('ResetClusterParameterGroup')
ResizeCluster = Action('ResizeCluster')
RestoreFromClusterSnapshot = Action('RestoreFromClusterSnapshot')
RestoreTableFromClusterSnapshot = \
    Action('RestoreTableFromClusterSnapshot')
ResumeCluster = Action('ResumeCluster')
RevokeClusterSecurityGroupIngress = \
    Action('RevokeClusterSecurityGroupIngress')
RevokeSnapshotAccess = Action('RevokeSnapshotAccess')
RotateEncryptionKey = Action('RotateEncryptionKey')
ViewQueriesFromConsole = Action('ViewQueriesFromConsole')
ViewQueriesInConsole = Action('ViewQueriesInConsole')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Cloud Directory'
prefix = 'clouddirectory'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddFacetToObject = Action('AddFacetToObject')
ApplySchema = Action('ApplySchema')
AttachObject = Action('AttachObject')
AttachPolicy = Action('AttachPolicy')
AttachToIndex = Action('AttachToIndex')
AttachTypedLink = Action('AttachTypedLink')
BatchRead = Action('BatchRead')
BatchWrite = Action('BatchWrite')
CreateDirectory = Action('CreateDirectory')
CreateFacet = Action('CreateFacet')
CreateIndex = Action('CreateIndex')
CreateObject = Action('CreateObject')
CreateSchema = Action('CreateSchema')
CreateTypedLinkFacet = Action('CreateTypedLinkFacet')
DeleteDirectory = Action('DeleteDirectory')
DeleteFacet = Action('DeleteFacet')
DeleteObject = Action('DeleteObject')
DeleteSchema = Action('DeleteSchema')
DeleteTypedLinkFacet = Action('DeleteTypedLinkFacet')
DetachFromIndex = Action('DetachFromIndex')
DetachObject = Action('DetachObject')
DetachPolicy = Action('DetachPolicy')
DetachTypedLink = Action('DetachTypedLink')
DisableDirectory = Action('DisableDirectory')
EnableDirectory = Action('EnableDirectory')
GetDirectory = Action('GetDirectory')
GetFacet = Action('GetFacet')
GetLinkAttributes = Action('GetLinkAttributes')
GetObjectAttributes = Action('GetObjectAttributes')
GetObjectInformation = Action('GetObjectInformation')
GetSchemaAsJson = Action('GetSchemaAsJson')
GetTypedLinkFacetInformation = Action('GetTypedLinkFacetInformation')
ListAppliedSchemaArns = Action('ListAppliedSchemaArns')
ListAttachedIndices = Action('ListAttachedIndices')
ListDevelopmentSchemaArns = Action('ListDevelopmentSchemaArns')
ListDirectories = Action('ListDirectories')
ListFacetAttributes = Action('ListFacetAttributes')
ListFacetNames = Action('ListFacetNames')
ListIncomingTypedLinks = Action('ListIncomingTypedLinks')
ListIndex = Action('ListIndex')
ListObjectAttributes = Action('ListObjectAttributes')
ListObjectChildren = Action('ListObjectChildren')
ListObjectParentPaths = Action('ListObjectParentPaths')
ListObjectParents = Action('ListObjectParents')
ListObjectPolicies = Action('ListObjectPolicies')
ListOutgoingTypedLinks = Action('ListOutgoingTypedLinks')
ListPolicyAttachments = Action('ListPolicyAttachments')
ListPublishedSchemaArns = Action('ListPublishedSchemaArns')
ListTagsForResource = Action('ListTagsForResource')
ListTypedLinkFacetAttributes = Action('ListTypedLinkFacetAttributes')
ListTypedLinkFacetNames = Action('ListTypedLinkFacetNames')
LookupPolicy = Action('LookupPolicy')
PublishSchema = Action('PublishSchema')
PutSchemaFromJson = Action('PutSchemaFromJson')
RemoveFacetFromObject = Action('RemoveFacetFromObject')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateFacet = Action('UpdateFacet')
UpdateLinkAttributes = Action('UpdateLinkAttributes')
UpdateObjectAttributes = Action('UpdateObjectAttributes')
UpdateSchema = Action('UpdateSchema')
UpdateTypedLinkFacet = Action('UpdateTypedLinkFacet')
